@@ -30,8 +30,7 @@ distribution) or else add the library to python's import path (the
 PYTHONPATH environment variable).
 
 For more information, see the README in the root of the library
-distribution or http://www.openidenabled.com/
-""")
+distribution.""")
     sys.exit(1)
 
 from openid.store import memstore
@@ -172,7 +171,7 @@ class OpenIDRequestHandler(BaseHTTPRequestHandler):
         oidconsumer = self.getConsumer(stateless = use_stateless)
         try:
             request = oidconsumer.begin(openid_url)
-        except consumer.DiscoveryFailure, exc:
+        except consumer.DiscoveryFailure as exc:
             fetch_error_string = 'Error in discovery: %s' % (
                 cgi.escape(str(exc[0])))
             self.render(fetch_error_string,
@@ -423,7 +422,7 @@ Content-type: text/html; charset=UTF-8
     <h1>%s</h1>
     <p>
       This example consumer uses the <a href=
-      "http://www.openidenabled.com/openid/libraries/python" >Python
+      "http://github.com/openid/python-openid" >Python
       OpenID</a> library. It just verifies that the identifier that you enter
       is your identifier.
     </p>
@@ -465,8 +464,8 @@ def main(host, port, data_path, weak_ssl=False):
     addr = (host, port)
     server = OpenIDHTTPServer(store, addr, OpenIDRequestHandler)
 
-    print 'Server running at:'
-    print server.base_url
+    print('Server running at:')
+    print(server.base_url)
     server.serve_forever()
 
 if __name__ == '__main__':
