@@ -135,7 +135,7 @@ class SessionNegotiator(object):
     """
 
     def __init__(self, allowed_types):
-        self.allowed_types = allowed_types
+        self.setAllowedTypes(allowed_types)
 
     def copy(self):
         return self.__class__(list(self.allowed_types))
@@ -511,7 +511,7 @@ class Association(object):
 
         signed_message = message.copy()
         signed_message.setArg(OPENID_NS, 'assoc_handle', self.handle)
-        message_keys = signed_message.toPostArgs().keys()
+        message_keys = list(signed_message.toPostArgs().keys())
         signed_list = [k[7:] for k in message_keys
                        if k.startswith('openid.')]
         signed_list.append('signed')
@@ -527,12 +527,12 @@ class Association(object):
 
         @raises ValueError: if the message has no signature or no signature
             can be calculated for it.
-        """        
+        """
         message_sig = message.getArg(OPENID_NS, 'sig')
         if not message_sig:
             raise ValueError("%s has no sig." % (message,))
         calculated_sig = self.getMessageSignature(message)
-        return calculated_sig == message_sig
+        return cryptutil.const_eq(calculated_sig, message_sig)
 
 
     def _makePairs(self, message):
