@@ -133,7 +133,7 @@ USING THIS LIBRARY
 
     Add an OpenID login field somewhere on your site.  When an OpenID
     is entered in that field and the form is submitted, it should make
-    a request to the your site which includes that OpenID URL.
+    a request to your site which includes that OpenID URL.
 
     First, the application should L{instantiate a Consumer<Consumer.__init__>}
     with a session for per-user state and store for shared state.
@@ -165,14 +165,13 @@ USING THIS LIBRARY
     the URL by the OpenID provider as the information necessary to
     finish the request.
 
-    Get an C{L{Consumer}} instance with the same session and store as
+    Get a C{L{Consumer}} instance with the same session and store as
     before and call its C{L{complete<Consumer.complete>}} method,
     passing in all the received query arguments.
 
     There are multiple possible return types possible from that
-    method. These indicate the whether or not the login was
-    successful, and include any additional information appropriate for
-    their type.
+    method. These indicate whether or not the login was successful,
+    and include any additional information appropriate for their type.
 
 @var SUCCESS: constant used as the status for
     L{SuccessResponse<openid.consumer.consumer.SuccessResponse>} objects.
@@ -190,7 +189,8 @@ USING THIS LIBRARY
 
 import cgi
 import copy
-from urlparse import urlparse, urldefrag
+import logging
+from urllib.parse import urlparse, urldefrag
 
 from openid import fetchers
 
@@ -343,7 +343,7 @@ class Consumer(object):
         disco = Discovery(self.session, user_url, self.session_key_prefix)
         try:
             service = disco.getNextService(self._discover)
-        except fetchers.HTTPFetchingError, why:
+        except fetchers.HTTPFetchingError as why:
             raise DiscoveryFailure(
                 'Error fetching XRDS document: %s' % (why[0],), None)
 
@@ -379,7 +379,7 @@ class Consumer(object):
 
         try:
             auth_req.setAnonymous(anonymous)
-        except ValueError, why:
+        except ValueError as why:
             raise ProtocolError(str(why))
 
         return auth_req
@@ -640,12 +640,12 @@ class GenericConsumer(object):
     def _complete_id_res(self, message, endpoint, return_to):
         try:
             self._checkSetupNeeded(message)
-        except SetupNeededError, why:
+        except SetupNeededError as why:
             return SetupNeededResponse(endpoint, why.user_setup_url)
         else:
             try:
                 return self._doIdRes(message, endpoint, return_to)
-            except (ProtocolError, DiscoveryFailure), why:
+            except (ProtocolError, DiscoveryFailure) as why:
                 return FailureResponse(endpoint, why[0])
 
     def _completeInvalid(self, message, endpoint, _):
@@ -662,8 +662,8 @@ class GenericConsumer(object):
         # message.
         try:
             self._verifyReturnToArgs(message.toPostArgs())
-        except ProtocolError, why:
-            oidutil.log("Verifying return_to arguments: %s" % (why[0],))
+        except ProtocolError as why:
+            logging.exception("Verifying return_to arguments: %s" % (why[0],))
             return False
 
         # Check the return_to base URL against the one in the message.
@@ -729,7 +729,7 @@ class GenericConsumer(object):
 
         # Verify discovery information:
         endpoint = self._verifyDiscoveryResults(message, endpoint)
-        oidutil.log("Received id_res response from %s using association %s" %
+        logging.info("Received id_res response from %s using association %s" %
                     (endpoint.server_url,
                      message.getArg(OPENID_NS, 'assoc_handle')))
 
@@ -769,7 +769,7 @@ class GenericConsumer(object):
 
         try:
             timestamp, salt = splitNonce(nonce)
-        except ValueError, why:
+        except ValueError as why:
             raise ProtocolError('Malformed nonce: %s' % (why[0],))
 
         if (self.store is not None and
@@ -868,7 +868,7 @@ class GenericConsumer(object):
         # Make sure all non-OpenID arguments in the response are also
         # in the signed return_to.
         bare_args = message.getArgs(BARE_NS)
-        for pair in bare_args.iteritems():
+        for pair in bare_args.items():
             if pair not in parsed_args:
                 raise ProtocolError("Parameter %s not in return_to URL" % (pair[0],))
 
@@ -923,7 +923,7 @@ class GenericConsumer(object):
         # endpoints and responses that didn't match the original
         # request.
         if not endpoint:
-            oidutil.log('No pre-discovered information supplied.')
+            logging.info('No pre-discovered information supplied.')
             endpoint = self._discoverAndVerify(to_match.claimed_id, [to_match])
         else:
             # The claimed ID matches, so we use the endpoint that we
@@ -931,11 +931,11 @@ class GenericConsumer(object):
             # case.
             try:
                 self._verifyDiscoverySingle(endpoint, to_match)
-            except ProtocolError, e:
-                oidutil.log(
+            except ProtocolError as e:
+                logging.exception(
                     "Error attempting to use stored discovery information: " +
                     str(e))
-                oidutil.log("Attempting discovery to verify endpoint")
+                logging.info("Attempting discovery to verify endpoint")
                 endpoint = self._discoverAndVerify(
                     to_match.claimed_id, [to_match])
 
@@ -976,10 +976,10 @@ class GenericConsumer(object):
                     self._verifyDiscoverySingle(endpoint, to_match)
                 except TypeURIMismatch:
                     self._verifyDiscoverySingle(endpoint, to_match_1_0)
-            except ProtocolError, e:
-                oidutil.log("Error attempting to use stored discovery information: " +
+            except ProtocolError as e:
+                logging.exception("Error attempting to use stored discovery information: " +
                             str(e))
-                oidutil.log("Attempting discovery to verify endpoint")
+                logging.info("Attempting discovery to verify endpoint")
             else:
                 return endpoint
 
@@ -1049,7 +1049,7 @@ class GenericConsumer(object):
 
         @raises DiscoveryFailure: when discovery fails.
         """
-        oidutil.log('Performing discovery on %s' % (claimed_id,))
+        logging.info('Performing discovery on %s' % (claimed_id,))
         _, services = self._discover(claimed_id)
         if not services:
             raise DiscoveryFailure('No OpenID information found at %s' %
@@ -1069,17 +1069,17 @@ class GenericConsumer(object):
                 try:
                     self._verifyDiscoverySingle(
                         endpoint, to_match_endpoint)
-                except ProtocolError, why:
+                except ProtocolError as why:
                     failure_messages.append(str(why))
                 else:
                     # It matches, so discover verification has
                     # succeeded. Return this endpoint.
                     return endpoint
         else:
-            oidutil.log('Discovery verification failure for %s' %
+            logging.error('Discovery verification failure for %s' %
                         (claimed_id,))
             for failure_message in failure_messages:
-                oidutil.log(' * Endpoint mismatch: ' + failure_message)
+                logging.error(' * Endpoint mismatch: ' + failure_message)
 
             raise DiscoveryFailure(
                 'No matching endpoint found after discovering %s'
@@ -1091,14 +1091,14 @@ class GenericConsumer(object):
         @returns: True if the request is valid.
         @rtype: bool
         """
-        oidutil.log('Using OpenID check_authentication')
+        logging.info('Using OpenID check_authentication')
         request = self._createCheckAuthRequest(message)
         if request is None:
             return False
         try:
             response = self._makeKVPost(request, server_url)
-        except (fetchers.HTTPFetchingError, ServerError), e:
-            oidutil.log('check_authentication failed: %s' % (e[0],))
+        except (fetchers.HTTPFetchingError, ServerError) as e:
+            logging.exception('check_authentication failed: %s' % (e[0],))
             return False
         else:
             return self._processCheckAuthResponse(response, server_url)
@@ -1110,12 +1110,12 @@ class GenericConsumer(object):
         signed = message.getArg(OPENID_NS, 'signed')
         if signed:
             for k in signed.split(','):
-                oidutil.log(k)
+                logging.info(k)
                 val = message.getAliasedArg(k)
 
                 # Signed value is missing
                 if val is None:
-                    oidutil.log('Missing signed field %r' % (k,))
+                    logging.info('Missing signed field %r' % (k,))
                     return None
 
         check_auth_message = message.copy()
@@ -1130,10 +1130,10 @@ class GenericConsumer(object):
 
         invalidate_handle = response.getArg(OPENID_NS, 'invalidate_handle')
         if invalidate_handle is not None:
-            oidutil.log(
+            logging.info(
                 'Received "invalidate_handle" from server %s' % (server_url,))
             if self.store is None:
-                oidutil.log('Unexpectedly got invalidate_handle without '
+                logging.error('Unexpectedly got invalidate_handle without '
                             'a store!')
             else:
                 self.store.removeAssociation(server_url, invalidate_handle)
@@ -1141,7 +1141,7 @@ class GenericConsumer(object):
         if is_valid == 'true':
             return True
         else:
-            oidutil.log('Server responds that checkAuth call is not valid')
+            logging.error('Server responds that checkAuth call is not valid')
             return False
 
     def _getAssociation(self, endpoint):
@@ -1179,7 +1179,7 @@ class GenericConsumer(object):
         try:
             assoc = self._requestAssociation(
                 endpoint, assoc_type, session_type)
-        except ServerError, why:
+        except ServerError as why:
             supportedTypes = self._extractSupportedAssociationType(why,
                                                                    endpoint,
                                                                    assoc_type)
@@ -1191,10 +1191,10 @@ class GenericConsumer(object):
                 try:
                     assoc = self._requestAssociation(
                         endpoint, assoc_type, session_type)
-                except ServerError, why:
+                except ServerError as why:
                     # Do not keep trying, since it rejected the
                     # association type that it told us to use.
-                    oidutil.log('Server %s refused its suggested association '
+                    logging.error('Server %s refused its suggested association '
                                 'type: session_type=%s, assoc_type=%s'
                                 % (endpoint.server_url, session_type,
                                    assoc_type))
@@ -1217,7 +1217,7 @@ class GenericConsumer(object):
         # should be considered a total failure.
         if server_error.error_code != 'unsupported-type' or \
                server_error.message.isOpenID1():
-            oidutil.log(
+            logging.error(
                 'Server error when requesting an association from %r: %s'
                 % (endpoint.server_url, server_error.error_text))
             return None
@@ -1225,7 +1225,7 @@ class GenericConsumer(object):
         # The server didn't like the association/session type
         # that we sent, and it sent us back a message that
         # might tell us how to handle it.
-        oidutil.log(
+        logging.error(
             'Unsupported association type %s: %s' % (assoc_type,
                                                      server_error.error_text,))
 
@@ -1235,13 +1235,13 @@ class GenericConsumer(object):
         session_type = server_error.message.getArg(OPENID_NS, 'session_type')
 
         if assoc_type is None or session_type is None:
-            oidutil.log('Server responded with unsupported association '
+            logging.error('Server responded with unsupported association '
                         'session but did not supply a fallback.')
             return None
         elif not self.negotiator.isAllowed(assoc_type, session_type):
             fmt = ('Server sent unsupported session/association type: '
                    'session_type=%s, assoc_type=%s')
-            oidutil.log(fmt % (session_type, assoc_type))
+            logging.error(fmt % (session_type, assoc_type))
             return None
         else:
             return assoc_type, session_type
@@ -1261,18 +1261,18 @@ class GenericConsumer(object):
 
         try:
             response = self._makeKVPost(args, endpoint.server_url)
-        except fetchers.HTTPFetchingError, why:
-            oidutil.log('openid.associate request failed: %s' % (why[0],))
+        except fetchers.HTTPFetchingError as why:
+            logging.exception('openid.associate request failed: %s' % (why[0],))
             return None
 
         try:
             assoc = self._extractAssociation(response, assoc_session)
-        except KeyError, why:
-            oidutil.log('Missing required parameter in response from %s: %s'
+        except KeyError as why:
+            logging.exception('Missing required parameter in response from %s: %s'
                         % (endpoint.server_url, why[0]))
             return None
-        except ProtocolError, why:
-            oidutil.log('Protocol error parsing response from %s: %s' % (
+        except ProtocolError as why:
+            logging.exception('Protocol error parsing response from %s: %s' % (
                 endpoint.server_url, why[0]))
             return None
         else:
@@ -1349,7 +1349,7 @@ class GenericConsumer(object):
         # OpenID 1, but we'll accept it anyway, while issuing a
         # warning.
         if session_type == 'no-encryption':
-            oidutil.log('WARNING: OpenID server sent "no-encryption"'
+            logging.warn('OpenID server sent "no-encryption"'
                         'for OpenID 1.X')
 
         # Missing or empty session type is the way to flag a
@@ -1394,7 +1394,7 @@ class GenericConsumer(object):
             OPENID_NS, 'expires_in', no_default)
         try:
             expires_in = int(expires_in_str)
-        except ValueError, why:
+        except ValueError as why:
             raise ProtocolError('Invalid expires_in field: %s' % (why[0],))
 
         # OpenID 1 has funny association session behaviour.
@@ -1432,7 +1432,7 @@ class GenericConsumer(object):
         # type.
         try:
             secret = assoc_session.extractSecret(assoc_response)
-        except ValueError, why:
+        except ValueError as why:
             fmt = 'Malformed response for %s session: %s'
             raise ProtocolError(fmt % (assoc_session.session_type, why[0]))
 
@@ -1596,11 +1596,11 @@ class AuthRequest(object):
 
         if self.assoc:
             message.setArg(OPENID_NS, 'assoc_handle', self.assoc.handle)
-            assoc_log_msg = 'with assocication %s' % (self.assoc.handle,)
+            assoc_log_msg = 'with association %s' % (self.assoc.handle,)
         else:
             assoc_log_msg = 'using stateless mode.'
 
-        oidutil.log("Generated %s request to %s %s" %
+        logging.info("Generated %s request to %s %s" %
                     (mode, self.endpoint.server_url, assoc_log_msg))
 
         return message
@@ -1669,9 +1669,9 @@ class AuthRequest(object):
 
         @returns: str
         """
-        return oidutil.autoSubmitHTML(self.formMarkup(realm, 
+        return oidutil.autoSubmitHTML(self.formMarkup(realm,
                                                       return_to,
-                                                      immediate, 
+                                                      immediate,
                                                       form_tag_attrs))
 
     def shouldSendRedirect(self):
@@ -1778,9 +1778,9 @@ class SuccessResponse(Response):
         """
         msg_args = self.message.getArgs(ns_uri)
 
-        for key in msg_args.iterkeys():
+        for key in msg_args.keys():
             if not self.isSigned(ns_uri, key):
-                oidutil.log("SuccessResponse.getSignedNS: (%s, %s) not signed."
+                logging.info("SuccessResponse.getSignedNS: (%s, %s) not signed."
                             % (ns_uri, key))
                 return None
 
