@@ -46,6 +46,7 @@ else:
     class HashContainer(object):
         def __init__(self, hash_constructor):
             self.new = hash_constructor
+            self.digest_size = hash_constructor().digest_size
 
     sha1_module = HashContainer(hashlib.sha1)
     sha256_module = HashContainer(hashlib.sha256)
@@ -96,7 +97,7 @@ except ImportError:
         reversed
     except NameError:
         def reversed(seq):
-            return map(seq.__getitem__, xrange(len(seq) - 1, -1, -1))
+            return list(map(seq.__getitem__, range(len(seq) - 1, -1, -1)))
 
     def longToBinary(l):
         if l == 0:
@@ -216,4 +217,14 @@ def randomString(length, chrs=None):
         return getBytes(length)
     else:
         n = len(chrs)
-        return ''.join([chrs[randrange(n)] for _ in xrange(length)])
+        return ''.join([chrs[randrange(n)] for _ in range(length)])
+
+def const_eq(s1, s2):
+    if len(s1) != len(s2):
+        return False
+
+    result = True
+    for i in range(len(s1)):
+        result = result and (s1[i] == s2[i])
+
+    return result
