@@ -1,50 +1,35 @@
-"""Utilities for key-value format conversions."""
-from __future__ import unicode_literals
-
-import logging
-
-import six
-
-from .oidutil import string_to_text
-
 __all__ = ['seqToKV', 'kvToSeq', 'dictToKV', 'kvToDict']
 
-
-_LOGGER = logging.getLogger(__name__)
-
+import types
+import logging
 
 class KVFormError(ValueError):
     pass
 
-
 def seqToKV(seq, strict=False):
     """Represent a sequence of pairs of strings as newline-terminated
     key:value pairs. The pairs are generated in the order given.
 
     @param seq: The pairs
-    @type seq: List[Tuple[six.text_type, six.text_type]], binary_type values are deprecated.
+    @type seq: [(str, (unicode|str))]
 
     @return: A string representation of the sequence
-    @rtype: six.text_type
+    @rtype: str
     """
     def err(msg):
         formatted = 'seqToKV warning: %s: %r' % (msg, seq)
         if strict:
             raise KVFormError(formatted)
         else:
-            _LOGGER.debug(formatted)
+            logging.warn(formatted)
 
     lines = []
     for k, v in seq:
-        if not isinstance(k, (six.text_type, six.binary_type)):
-            err('Converting key to text: %r' % k)
-            k = six.text_type(k)
-        if not isinstance(v, (six.text_type, six.binary_type)):
-            err('Converting value to text: %r' % v)
-            v = six.text_type(v)
-
-        k = string_to_text(k, "Binary values for keys are deprecated. Use text input instead.")
-        v = string_to_text(v, "Binary values for values are deprecated. Use text input instead.")
+        if isinstance(k, bytes):
+            k = k.decode('UTF8')
+        elif not isinstance(k, str):
+            err('Converting key to string: %r' % k)
+            k = str(k)
 
         if '\n' in k:
             raise KVFormError(
@@ -57,6 +42,12 @@ def seqToKV(seq, strict=False):
         if k.strip() != k:
             err('Key has whitespace at beginning or end: %r' % (k,))
 
+        if isinstance(v, bytes):
+            v = v.decode('UTF8')
+        elif not isinstance(v, str):
+            err('Converting value to string: %r' % (v,))
+            v = str(v)
+
         if '\n' in v:
             raise KVFormError(
                 'Invalid input for seqToKV: value contains newline: %r' % (v,))
@@ -66,30 +57,22 @@ def seqToKV(seq, strict=False):
 
         lines.append(k + ':' + v + '\n')
 
-    return ''.join(lines)
-
+    return ''.join(lines).encode('UTF8')
 
 def kvToSeq(data, strict=False):
     """
-    Parse newline-terminated key:value pair string into a sequence.
 
     After one parse, seqToKV and kvToSeq are inverses, with no warnings::
 
         seq = kvToSeq(s)
         seqToKV(kvToSeq(seq)) == seq
-
-    @type data: six.text_type, six.binary_type is deprecated
-
-    @rtype: List[Tuple[six.text_type, six.text_type]]
     """
     def err(msg):
         formatted = 'kvToSeq warning: %s: %r' % (msg, data)
         if strict:
             raise KVFormError(formatted)
         else:
-            _LOGGER.debug(formatted)
-
-    data = string_to_text(data, "Binary values for data are deprecated. Use text input instead.")
+            logging.warn(formatted)
 
     lines = data.split('\n')
     if lines[-1]:
@@ -124,17 +107,16 @@ def kvToSeq(data, strict=False):
                        'whitespace in value %r')
                 err(fmt % (line_num, v))
 
-            pairs.append((k_s, v_s))
+            pairs.append((k_s.decode('UTF8'), v_s.decode('UTF8')))
         else:
             err('Line %d does not contain a colon' % line_num)
 
     return pairs
 
-
 def dictToKV(d):
-    seq = sorted(d.items())
+    seq = list(d.items())
+    seq.sort()
     return seqToKV(seq)
 
-
 def kvToDict(s):
     return dict(kvToSeq(s))
