@@ -1,10 +1,9 @@
 """A simple store using only in-process memory."""
 
-import copy
-import time
-
 from openid.store import nonce
 
+import copy
+import time
 
 class ServerAssocs(object):
     def __init__(self):
@@ -30,7 +29,7 @@ class ServerAssocs(object):
         or None if there are no associations.
         """
         best = None
-        for assoc in self.assocs.values():
+        for assoc in list(self.assocs.values()):
             if best is None or best.issued < assoc.issued:
                 best = assoc
         return best
@@ -41,7 +40,7 @@ class ServerAssocs(object):
         @return: tuple of (removed associations, remaining associations)
         """
         remove = []
-        for handle, assoc in self.assocs.iteritems():
+        for handle, assoc in self.assocs.items():
             if assoc.getExpiresIn() == 0:
                 remove.append(handle)
         for handle in remove:
@@ -49,12 +48,12 @@ class ServerAssocs(object):
         return len(remove), len(self.assocs)
 
 
+
 class MemoryStore(object):
     """In-process memory store.
 
     Use for single long-running processes.  No persistence supplied.
     """
-
     def __init__(self):
         self.server_assocs = {}
         self.nonces = {}
@@ -95,7 +94,7 @@ class MemoryStore(object):
     def cleanupNonces(self):
         now = time.time()
         expired = []
-        for anonce in self.nonces.iterkeys():
+        for anonce in self.nonces.keys():
             if abs(anonce[1] - now) > nonce.SKEW:
                 # removing items while iterating over the set could be bad.
                 expired.append(anonce)
@@ -107,7 +106,7 @@ class MemoryStore(object):
     def cleanupAssociations(self):
         remove_urls = []
         removed_assocs = 0
-        for server_url, assocs in self.server_assocs.iteritems():
+        for server_url, assocs in self.server_assocs.items():
             removed, remaining = assocs.cleanup()
             removed_assocs += removed
             if not remaining:
