@@ -4,12 +4,16 @@
 import unittest
 from openid.extensions import ax
 from openid.message import NamespaceMap, Message, OPENID2_NS
+from openid.consumer.consumer import SuccessResponse
 
 class BogusAXMessage(ax.AXMessage):
     mode = 'bogus'
 
     getExtensionArgs = ax.AXMessage._newArgs
 
+class DummyRequest(object):
+    def __init__(self, message):
+        self.message = message
 
 class AXMessageTest(unittest.TestCase):
     def setUp(self):
@@ -17,7 +21,7 @@ class AXMessageTest(unittest.TestCase):
 
     def test_checkMode(self):
         check = self.bax._checkMode
-        self.failUnlessRaises(ax.AXError, check, {})
+        self.failUnlessRaises(ax.NotAXMessage, check, {})
         self.failUnlessRaises(ax.AXError, check, {'mode':'fetch_request'})
 
         # does not raise an exception when the mode is right
@@ -25,6 +29,7 @@ class AXMessageTest(unittest.TestCase):
 
     def test_checkMode_newArgs(self):
         """_newArgs generates something that has the correct mode"""
+        # This would raise AXError if it didn't like the mode newArgs made.
         self.bax._checkMode(self.bax._newArgs())
 
 
@@ -74,11 +79,14 @@ class ToTypeURIsTest(unittest.TestCase):
         self.failUnlessEqual([uri1, uri2], uris)
 
 class ParseAXValuesTest(unittest.TestCase):
+    """Testing AXKeyValueMessage.parseExtensionArgs."""
+
     def failUnlessAXKeyError(self, ax_args):
         msg = ax.AXKeyValueMessage()
         self.failUnlessRaises(KeyError, msg.parseExtensionArgs, ax_args)
 
     def failUnlessAXValues(self, ax_args, expected_args):
+        """Fail unless parseExtensionArgs(ax_args) == expected_args."""
         msg = ax.AXKeyValueMessage()
         msg.parseExtensionArgs(ax_args)
         self.failUnlessEqual(expected_args, msg.data)
@@ -230,7 +238,7 @@ class FetchRequestTest(unittest.TestCase):
             )
         self.msg.add(attr)
         ax_args = self.msg.getExtensionArgs()
-        for k, v in ax_args.iteritems():
+        for k, v in ax_args.items():
             if v == attr.type_uri and k.startswith('type.'):
                 alias = k[5:]
                 break
@@ -349,10 +357,9 @@ class FetchRequestTest(unittest.TestCase):
             'ax.update_url': 'http://different.site/path',
             'ax.mode': 'fetch_request',
             })
-
         self.failUnlessRaises(ax.AXError,
                               ax.FetchRequest.fromOpenIDRequest,
-                              openid_req_msg)
+                              DummyRequest(openid_req_msg))
 
     def test_openidUpdateURLVerificationError(self):
         openid_req_msg = Message.fromOpenIDArgs({
@@ -366,7 +373,7 @@ class FetchRequestTest(unittest.TestCase):
 
         self.failUnlessRaises(ax.AXError,
                               ax.FetchRequest.fromOpenIDRequest,
-                              openid_req_msg)
+                              DummyRequest(openid_req_msg))
 
     def test_openidUpdateURLVerificationSuccess(self):
         openid_req_msg = Message.fromOpenIDArgs({
@@ -378,7 +385,7 @@ class FetchRequestTest(unittest.TestCase):
             'ax.mode': 'fetch_request',
             })
 
-        fr = ax.FetchRequest.fromOpenIDRequest(openid_req_msg)
+        fr = ax.FetchRequest.fromOpenIDRequest(DummyRequest(openid_req_msg))
 
     def test_openidUpdateURLVerificationSuccessReturnTo(self):
         openid_req_msg = Message.fromOpenIDArgs({
@@ -390,7 +397,32 @@ class FetchRequestTest(unittest.TestCase):
             'ax.mode': 'fetch_request',
             })
 
-        fr = ax.FetchRequest.fromOpenIDRequest(openid_req_msg)
+        fr = ax.FetchRequest.fromOpenIDRequest(DummyRequest(openid_req_msg))
+
+    def test_fromOpenIDRequestWithoutExtension(self):
+        """return None for an OpenIDRequest without AX paramaters."""
+        openid_req_msg = Message.fromOpenIDArgs({
+            'mode': 'checkid_setup',
+            'ns': OPENID2_NS,
+            })
+        oreq = DummyRequest(openid_req_msg)
+        r = ax.FetchRequest.fromOpenIDRequest(oreq)
+        self.failUnless(r is None, "%s is not None" % (r,))
+
+    def test_fromOpenIDRequestWithoutData(self):
+        """return something for SuccessResponse with AX paramaters,
+        even if it is the empty set."""
+        openid_req_msg = Message.fromOpenIDArgs({
+            'mode': 'checkid_setup',
+            'realm': 'http://example.com/realm',
+            'ns': OPENID2_NS,
+            'ns.ax': ax.AXMessage.ns_uri,
+            'ax.mode': 'fetch_request',
+            })
+        oreq = DummyRequest(openid_req_msg)
+        r = ax.FetchRequest.fromOpenIDRequest(oreq)
+        self.failUnless(r is not None)
+
 
 class FetchResponseTest(unittest.TestCase):
     def setUp(self):
@@ -481,6 +513,63 @@ class FetchResponseTest(unittest.TestCase):
     def test_get(self):
         self.failUnlessRaises(KeyError, self.msg.get, self.type_a)
 
+    def test_fromSuccessResponseWithoutExtension(self):
+        """return None for SuccessResponse with no AX paramaters."""
+        args = {
+            'mode': 'id_res',
+            'ns': OPENID2_NS,
+            }
+        sf = ['openid.' + i for i in list(args.keys())]
+        msg = Message.fromOpenIDArgs(args)
+        class Endpoint:
+            claimed_id = 'http://invalid.'
+
+        oreq = SuccessResponse(Endpoint(), msg, signed_fields=sf)
+        r = ax.FetchResponse.fromSuccessResponse(oreq)
+        self.failUnless(r is None, "%s is not None" % (r,))
+
+    def test_fromSuccessResponseWithoutData(self):
+        """return something for SuccessResponse with AX paramaters,
+        even if it is the empty set."""
+        args = {
+            'mode': 'id_res',
+            'ns': OPENID2_NS,
+            'ns.ax': ax.AXMessage.ns_uri,
+            'ax.mode': 'fetch_response',
+            }
+        sf = ['openid.' + i for i in list(args.keys())]
+        msg = Message.fromOpenIDArgs(args)
+        class Endpoint:
+            claimed_id = 'http://invalid.'
+
+        oreq = SuccessResponse(Endpoint(), msg, signed_fields=sf)
+        r = ax.FetchResponse.fromSuccessResponse(oreq)
+        self.failUnless(r is not None)
+
+    def test_fromSuccessResponseWithData(self):
+        name = 'ext0'
+        value = 'snozzberry'
+        uri = "http://willy.wonka.name/"
+        args = {
+            'mode': 'id_res',
+            'ns': OPENID2_NS,
+            'ns.ax': ax.AXMessage.ns_uri,
+            'ax.update_url': 'http://example.com/realm/update_path',
+            'ax.mode': 'fetch_response',
+            'ax.type.'+name: uri,
+            'ax.count.'+name: '1',
+            'ax.value.%s.1'%name: value,
+            }
+        sf = ['openid.' + i for i in list(args.keys())]
+        msg = Message.fromOpenIDArgs(args)
+        class Endpoint:
+            claimed_id = 'http://invalid.'
+
+        resp = SuccessResponse(Endpoint(), msg, signed_fields=sf)
+        ax_resp = ax.FetchResponse.fromSuccessResponse(resp)
+        values = ax_resp.get(uri)
+        self.failUnlessEqual([value], values)
+
 
 class StoreRequestTest(unittest.TestCase):
     def setUp(self):
