@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 import sys
 import unittest
-import datadriven
+from . import datadriven
 import os.path
 from openid import fetchers
 from openid.fetchers import HTTPResponse
@@ -8,7 +9,7 @@ from openid.yadis.discover import DiscoveryFailure
 from openid.consumer import discover
 from openid.yadis import xrires
 from openid.yadis.xri import XRI
-from urlparse import urlsplit
+from urllib.parse import urlsplit
 from openid import message
 
 ### Tests for conditions that trigger DiscoveryFailure
@@ -50,7 +51,7 @@ class TestDiscoveryFailure(datadriven.DataDrivenTestCase):
         expected_status = self.responses[-1].status
         try:
             discover.discover(self.url)
-        except DiscoveryFailure, why:
+        except DiscoveryFailure as why:
             self.failUnlessEqual(why.http_response.status, expected_status)
         else:
             self.fail('Did not raise DiscoveryFailure')
@@ -88,9 +89,12 @@ class TestFetchException(datadriven.DataDrivenTestCase):
         DidFetch(),
         ValueError(),
         RuntimeError(),
-        'oi!',
         ]
 
+    # String exceptions are finally gone from Python 2.6.
+    if sys.version_info[:2] < (2, 6):
+        cases.append('oi!')
+
     def __init__(self, exc):
         datadriven.DataDrivenTestCase.__init__(self, repr(exc))
         self.exc = exc
@@ -125,7 +129,7 @@ class TestNormalization(unittest.TestCase):
 
         try:
             discover.discover('users.stompy.janrain.com:8000/x')
-        except DiscoveryFailure, why:
+        except DiscoveryFailure as why:
             self.fail('failed to parse url with port correctly')
         except RuntimeError:
             pass #expected
@@ -245,6 +249,37 @@ class TestDiscovery(BaseTestDiscovery):
         self.failUnlessRaises(DiscoveryFailure,
                               discover.discover, self.id_url + '/404')
 
+    def test_unicode(self):
+        """
+        Check page with unicode and HTML entities
+        """
+        self._discover(
+            content_type='text/html;charset=utf-8',
+            data=readDataFile('unicode.html'),
+            expected_services=0)
+
+    def test_unicode_undecodable_html(self):
+        """
+        Check page with unicode and HTML entities that can not be decoded
+        """
+        data = readDataFile('unicode2.html')
+        self.failUnlessRaises(UnicodeDecodeError, data.decode, 'utf-8')
+        self._discover(content_type='text/html;charset=utf-8',
+            data=data, expected_services=0)
+
+    def test_unicode_undecodable_html2(self):
+        """
+        Check page with unicode and HTML entities that can not be decoded
+        but xrds document is found before it matters
+        """
+        self.documents[self.id_url + 'xrds'] = (
+            'application/xrds+xml', readDataFile('yadis_idp.xml'))
+
+        data = readDataFile('unicode3.html')
+        self.failUnlessRaises(UnicodeDecodeError, data.decode, 'utf-8')
+        self._discover(content_type='text/html;charset=utf-8',
+            data=data, expected_services=1)
+
     def test_noOpenID(self):
         services = self._discover(content_type='text/plain',
                                   data="junk",
@@ -546,6 +581,31 @@ class TestXRIDiscovery(BaseTestDiscovery):
             display_identifier='=smoker'
             )
 
+    def test_xri_normalize(self):
+        user_xri, services = discover.discoverXRI('xri://=smoker')
+
+        self._checkService(
+            services[0],
+            used_yadis=True,
+            types=['1.0'],
+            server_url="http://www.myopenid.com/server",
+            claimed_id=XRI("=!1000"),
+            canonical_id=XRI("=!1000"),
+            local_id='http://smoker.myopenid.com/',
+            display_identifier='=smoker'
+            )
+
+        self._checkService(
+            services[1],
+            used_yadis=True,
+            types=['1.0'],
+            server_url="http://www.livejournal.com/openid/server.bml",
+            claimed_id=XRI("=!1000"),
+            canonical_id=XRI("=!1000"),
+            local_id='http://frank.livejournal.com/',
+            display_identifier='=smoker'
+            )
+
     def test_xriNoCanonicalID(self):
         user_xri, services = discover.discoverXRI('=smoker*bad')
         self.failIf(services)
