@@ -162,6 +162,10 @@ class TestCanonicalID(unittest.TestCase):
 
     test_status222 = mkTest("=x", "status222.xrds", None)
 
+    test_multisegment_xri = mkTest('xri://=nishitani*masaki',
+                                   'subsegments.xrds',
+                                   '=!E117.EF2F.454B.C707!0000.0000.3B9A.CA01')
+
     test_iri_auth_not_allowed = mkTest(
         "phreak.example.com", "delegated-20060809-r2.xrds", etxrd.XRDSFraud)
     test_iri_auth_not_allowed.__doc__ = \
@@ -175,7 +179,7 @@ class TestCanonicalID(unittest.TestCase):
     #   somewhere in the resolution chain.
 
     def _getCanonicalID(self, iname, xrds, expectedID):
-        if isinstance(expectedID, (str, unicode, type(None))):
+        if isinstance(expectedID, (str, type(None))):
             cid = etxrd.getCanonicalID(iname, xrds)
             self.failUnlessEqual(cid, expectedID and xri.XRI(expectedID))
         elif issubclass(expectedID, etxrd.XRDSError):
