@@ -1,7 +1,5 @@
 from openid.consumer.discover import OpenIDServiceEndpoint
-from openid.consumer.parse import openIDDiscover as parseOpenIDLinkRel
-from openid.consumer.parse import ParseError
-import datadriven
+from . import datadriven
 
 class BadLinksTestCase(datadriven.DataDrivenTestCase):
     cases = [
@@ -14,15 +12,10 @@ class BadLinksTestCase(datadriven.DataDrivenTestCase):
         datadriven.DataDrivenTestCase.__init__(self, data)
         self.data = data
 
-    def callFunc(self):
-        return parseOpenIDLinkRel(self.data)
-
     def runOneTest(self):
-        self.failUnlessRaises(ParseError, self.callFunc)
-
-class BadLinksThroughEndpoint(BadLinksTestCase):
-    def callFunc(self):
-        return OpenIDServiceEndpoint.fromHTML('http://unused.url/', self.data)
+        actual = OpenIDServiceEndpoint.fromHTML('http://unused.url/', self.data)
+        expected = []
+        self.failUnlessEqual(expected, actual)
 
 def pyUnitTests():
     return datadriven.loadTests(__name__)
