@@ -1,10 +1,11 @@
+# -*- coding: utf-8 -*-
 from openid import message
 from openid import oidutil
+from openid.extensions import sreg
 
-import urllib
+import urllib.request, urllib.parse, urllib.error
 import cgi
 import unittest
-import datadriven
 
 def mkGetArgTest(ns, key, expected=None):
     def test(self):
@@ -88,6 +89,17 @@ class EmptyMessageTest(unittest.TestCase):
         self.failUnlessEqual(self.msg.hasKey('urn:nothing-significant', 'foo'),
                              False)
 
+    def test_getAliasedArgSuccess(self):
+        msg = message.Message.fromPostArgs({'openid.ns.test': 'urn://foo',
+                                            'openid.test.flub': 'bogus'})
+        actual_uri = msg.getAliasedArg('ns.test', message.no_default)
+        self.assertEquals("urn://foo", actual_uri)
+    
+    def test_getAliasedArgFailure(self):
+        msg = message.Message.fromPostArgs({'openid.test.flub': 'bogus'})
+        self.assertRaises(KeyError,
+                          msg.getAliasedArg, 'ns.test', message.no_default)
+
     def test_getArg(self):
         # Could reasonably return None instead of raising an
         # exception. I'm not sure which one is more right, since this
@@ -390,13 +402,49 @@ class OpenID1MessageTest(unittest.TestCase):
     def test_isOpenID2(self):
         self.failIf(self.msg.isOpenID2())
 
-class OpenID1ExplicitMessageTest(OpenID1MessageTest):
+class OpenID1ExplicitMessageTest(unittest.TestCase):
     def setUp(self):
         self.msg = message.Message.fromPostArgs({'openid.mode':'error',
                                                  'openid.error':'unit test',
                                                  'openid.ns':message.OPENID1_NS
                                                  })
 
+    def test_toPostArgs(self):
+        self.failUnlessEqual(self.msg.toPostArgs(),
+                             {'openid.mode':'error',
+                              'openid.error':'unit test',
+                              'openid.ns':message.OPENID1_NS
+                              })
+
+    def test_toArgs(self):
+        self.failUnlessEqual(self.msg.toArgs(), {'mode':'error',
+                                                 'error':'unit test',
+                                                 'ns':message.OPENID1_NS})
+
+    def test_toKVForm(self):
+        self.failUnlessEqual(self.msg.toKVForm(),
+                             'error:unit test\nmode:error\nns:%s\n'
+                              %message.OPENID1_NS)
+
+    def test_toURLEncoded(self):
+        self.failUnlessEqual(self.msg.toURLEncoded(),
+                             'openid.error=unit+test&openid.mode=error&openid.ns=http%3A%2F%2Fopenid.net%2Fsignon%2F1.0')
+
+    def test_toURL(self):
+        base_url = 'http://base.url/'
+        actual = self.msg.toURL(base_url)
+        actual_base = actual[:len(base_url)]
+        self.failUnlessEqual(actual_base, base_url)
+        self.failUnlessEqual(actual[len(base_url)], '?')
+        query = actual[len(base_url) + 1:]
+        parsed = cgi.parse_qs(query)
+        self.failUnlessEqual(parsed, {'openid.mode':['error'],
+                                      'openid.error':['unit test'],
+                                      'openid.ns':[message.OPENID1_NS]
+                                      })
+
+    def test_isOpenID1(self):
+        self.failUnless(self.msg.isOpenID1())
 
 class OpenID2MessageTest(unittest.TestCase):
     def setUp(self):
@@ -414,6 +462,20 @@ class OpenID2MessageTest(unittest.TestCase):
                               'xey': 'value',
                               })
 
+    def test_toPostArgs_bug_with_utf8_encoded_values(self):
+        msg = message.Message.fromPostArgs({'openid.mode':'error',
+                                            'openid.error':'unit test',
+                                            'openid.ns':message.OPENID2_NS
+                                             })
+        msg.setArg(message.BARE_NS, 'ünicöde_key', 'ünicöde_välüe')
+        self.failUnlessEqual(msg.toPostArgs(),
+                             {'openid.mode':'error',
+                              'openid.error':'unit test',
+                              'openid.ns':message.OPENID2_NS,
+                              'ünicöde_key': 'ünicöde_välüe',
+                              })
+
+
     def test_toArgs(self):
         # This method can't tolerate BARE_NS.
         self.msg.delArg(message.BARE_NS, "xey")
@@ -432,7 +494,7 @@ class OpenID2MessageTest(unittest.TestCase):
     def _test_urlencoded(self, s):
         expected = ('openid.error=unit+test&openid.mode=error&'
                     'openid.ns=%s&xey=value' % (
-            urllib.quote(message.OPENID2_NS, ''),))
+            urllib.parse.quote(message.OPENID2_NS, ''),))
         self.failUnlessEqual(s, expected)
 
 
@@ -584,6 +646,71 @@ class OpenID2MessageTest(unittest.TestCase):
             self.failUnlessRaises(AssertionError, self.msg.fromPostArgs,
                                   args)
 
+    def test_mysterious_missing_namespace_bug(self):
+        """A failing test for bug #112"""
+        openid_args = {
+          'assoc_handle': '{{HMAC-SHA256}{1211477242.29743}{v5cadg==}',
+          'claimed_id': 'http://nerdbank.org/OPAffirmative/AffirmativeIdentityWithSregNoAssoc.aspx', 
+          'ns.sreg': 'http://openid.net/extensions/sreg/1.1', 
+          'response_nonce': '2008-05-22T17:27:22ZUoW5.\\NV', 
+          'signed': 'return_to,identity,claimed_id,op_endpoint,response_nonce,ns.sreg,sreg.email,sreg.nickname,assoc_handle',
+          'sig': 'e3eGZ10+TNRZitgq5kQlk5KmTKzFaCRI8OrRoXyoFa4=', 
+          'mode': 'check_authentication', 
+          'op_endpoint': 'http://nerdbank.org/OPAffirmative/ProviderNoAssoc.aspx',
+          'sreg.nickname': 'Andy',
+          'return_to': 'http://localhost.localdomain:8001/process?janrain_nonce=2008-05-22T17%3A27%3A21ZnxHULd', 
+          'invalidate_handle': '{{HMAC-SHA1}{1211477241.92242}{H0akXw==}', 
+          'identity': 'http://nerdbank.org/OPAffirmative/AffirmativeIdentityWithSregNoAssoc.aspx', 
+          'sreg.email': 'a@b.com'
+          }
+        m = message.Message.fromOpenIDArgs(openid_args)
+
+        self.failUnless(('http://openid.net/extensions/sreg/1.1', 'sreg') in
+                        list(m.namespaces.items()))
+        missing = []
+        for k in openid_args['signed'].split(','):
+            if not ("openid."+k) in list(m.toPostArgs().keys()):
+                missing.append(k)
+        self.assertEqual([], missing, missing)
+        self.assertEqual(openid_args, m.toArgs())
+        self.failUnless(m.isOpenID1())
+
+    def test_112B(self):
+        args = {'openid.assoc_handle': 'fa1f5ff0-cde4-11dc-a183-3714bfd55ca8',
+                'openid.claimed_id': 'http://binkley.lan/user/test01',
+                'openid.identity': 'http://test01.binkley.lan/',
+                'openid.mode': 'id_res',
+                'openid.ns': 'http://specs.openid.net/auth/2.0',
+                'openid.ns.pape': 'http://specs.openid.net/extensions/pape/1.0',
+                'openid.op_endpoint': 'http://binkley.lan/server',
+                'openid.pape.auth_policies': 'none',
+                'openid.pape.auth_time': '2008-01-28T20:42:36Z',
+                'openid.pape.nist_auth_level': '0',
+                'openid.response_nonce': '2008-01-28T21:07:04Z99Q=',
+                'openid.return_to': 'http://binkley.lan:8001/process?janrain_nonce=2008-01-28T21%3A07%3A02Z0tMIKx',
+                'openid.sig': 'YJlWH4U6SroB1HoPkmEKx9AyGGg=',
+                'openid.signed': 'assoc_handle,identity,response_nonce,return_to,claimed_id,op_endpoint,pape.auth_time,ns.pape,pape.nist_auth_level,pape.auth_policies'
+                }
+        m = message.Message.fromPostArgs(args)
+        missing = []
+        for k in args['openid.signed'].split(','):
+            if not ("openid."+k) in list(m.toPostArgs().keys()):
+                missing.append(k)
+        self.assertEqual([], missing, missing)
+        self.assertEqual(args, m.toPostArgs())
+        self.failUnless(m.isOpenID2())
+
+    def test_implicit_sreg_ns(self):
+        openid_args = {
+          'sreg.email': 'a@b.com'
+          }
+        m = message.Message.fromOpenIDArgs(openid_args)
+        self.failUnless((sreg.ns_uri, 'sreg') in
+                        list(m.namespaces.items()))
+        self.assertEqual('a@b.com', m.getArg(sreg.ns_uri, 'email'))
+        self.assertEqual(openid_args, m.toArgs())
+        self.failUnless(m.isOpenID1())
+
     def _test_delArgNS(self, ns):
         key = 'Camper van Beethoven'
         value = 'David Lowery'
@@ -668,13 +795,13 @@ class MessageTest(unittest.TestCase):
         form = input_tree.getroot()
 
         # Check required form attributes
-        for k, v in self.required_form_attrs.iteritems():
+        for k, v in self.required_form_attrs.items():
             assert form.attrib[k] == v, \
                    "Expected '%s' for required form attribute '%s', got '%s'" % \
                    (v, k, form.attrib[k])
 
         # Check extra form attributes
-        for k, v in form_tag_attrs.iteritems():
+        for k, v in form_tag_attrs.items():
 
             # Skip attributes that already passed the required
             # attribute check, since they should be ignored by the
@@ -693,7 +820,7 @@ class MessageTest(unittest.TestCase):
 
         # For each post arg, make sure there is a hidden with that
         # value.  Make sure there are no other hiddens.
-        for name, value in message_.toPostArgs().iteritems():
+        for name, value in message_.toPostArgs().items():
             for e in hiddens:
                 if e.attrib['name'] == name:
                     assert e.attrib['value'] == value, \
@@ -704,7 +831,7 @@ class MessageTest(unittest.TestCase):
                 self.fail("Post arg '%s' not found in form" % (name,))
 
         for e in hiddens:
-            assert e.attrib['name'] in message_.toPostArgs().keys(), \
+            assert e.attrib['name'] in list(message_.toPostArgs().keys()), \
                    "Form element for '%s' not in " + \
                    "original message" % (e.attrib['name'])
 
@@ -733,6 +860,29 @@ class MessageTest(unittest.TestCase):
         self._checkForm(html, m, self.action_url,
                         self.form_tag_attrs, self.submit_text)
 
+    def test_toFormMarkup_bug_with_utf8_values(self):
+        postargs = {
+            'openid.ns': message.OPENID2_NS,
+            'openid.mode': 'checkid_setup',
+            'openid.identity': 'http://bogus.example.invalid:port/',
+            'openid.assoc_handle': 'FLUB',
+            'openid.return_to': 'Neverland',
+            'ünicöde_key' : 'ünicöde_välüe',
+            }
+        m = message.Message.fromPostArgs(postargs)
+        # Calling m.toFormMarkup with lxml used for ElementTree will throw
+        # a ValueError.
+        html = m.toFormMarkup(self.action_url, self.form_tag_attrs,
+                              self.submit_text)
+        # Using the (c)ElementTree from stdlib will result in the UTF-8
+        # encoded strings to be converted to XML character references,
+        # "ünicöde_key" becomes "&#195;&#188;nic&#195;&#182;de_key" and
+        # "ünicöde_välüe" becomes "&#195;&#188;nic&#195;&#182;de_v&#195;&#164;l&#195;&#188;e"
+        self.failIf('&#195;&#188;nic&#195;&#182;de_key' in html,
+                    'UTF-8 bytes should not convert to XML character references')
+        self.failIf('&#195;&#188;nic&#195;&#182;de_v&#195;&#164;l&#195;&#188;e' in html,
+                    'UTF-8 bytes should not convert to XML character references')
+
     def test_overrideMethod(self):
         """Be sure that caller cannot change form method to GET."""
         m = message.Message.fromPostArgs(self.postargs)
@@ -759,6 +909,87 @@ class MessageTest(unittest.TestCase):
         self._checkForm(html, m, self.action_url,
                         tag_attrs, self.submit_text)
 
+
+    def test_setOpenIDNamespace_invalid(self):
+        m = message.Message()
+        invalid_things = [
+            # Empty string is not okay here.
+            '',
+            # Good guess!  But wrong.
+            'http://openid.net/signon/2.0',
+            # What?
+            'http://specs%\\\r2Eopenid.net/auth/2.0',
+            # Too much escapings!
+            'http%3A%2F%2Fspecs.openid.net%2Fauth%2F2.0',
+            # This is a Type URI, not a openid.ns value.
+            'http://specs.openid.net/auth/2.0/signon',
+            ]
+
+        for x in invalid_things:
+            self.failUnlessRaises(message.InvalidOpenIDNamespace,
+                                  m.setOpenIDNamespace, x, False)
+
+
+    def test_isOpenID1(self):
+        v1_namespaces = [
+            # Yes, there are two of them.
+            'http://openid.net/signon/1.1',
+            'http://openid.net/signon/1.0',
+            ]
+
+        for ns in v1_namespaces:
+            m = message.Message(ns)
+            self.failUnless(m.isOpenID1(), "%r not recognized as OpenID 1" %
+                            (ns,))
+            self.failUnlessEqual(ns, m.getOpenIDNamespace())
+            self.failUnless(m.namespaces.isImplicit(ns),
+                            m.namespaces.getNamespaceURI(message.NULL_NAMESPACE))
+
+    def test_isOpenID2(self):
+        ns = 'http://specs.openid.net/auth/2.0'
+        m = message.Message(ns)
+        self.failUnless(m.isOpenID2())
+        self.failIf(m.namespaces.isImplicit(message.NULL_NAMESPACE))
+        self.failUnlessEqual(ns, m.getOpenIDNamespace())
+
+    def test_setOpenIDNamespace_explicit(self):
+        m = message.Message()
+        m.setOpenIDNamespace(message.THE_OTHER_OPENID1_NS, False)
+        self.failIf(m.namespaces.isImplicit(message.THE_OTHER_OPENID1_NS))
+
+    def test_setOpenIDNamespace_implicit(self):
+        m = message.Message()
+        m.setOpenIDNamespace(message.THE_OTHER_OPENID1_NS, True)
+        self.failUnless(m.namespaces.isImplicit(message.THE_OTHER_OPENID1_NS))
+
+
+    def test_explicitOpenID11NSSerialzation(self):
+        m = message.Message()
+        m.setOpenIDNamespace(message.THE_OTHER_OPENID1_NS, implicit=False)
+
+        post_args = m.toPostArgs()
+        self.failUnlessEqual(post_args,
+                             {'openid.ns':message.THE_OTHER_OPENID1_NS})
+
+    def test_fromPostArgs_ns11(self):
+        # An example of the stuff that some Drupal installations send us,
+        # which includes openid.ns but is 1.1.
+        query = {
+            'openid.assoc_handle': '',
+            'openid.claimed_id': 'http://foobar.invalid/',
+            'openid.identity': 'http://foobar.myopenid.com',
+            'openid.mode': 'checkid_setup',
+            'openid.ns': 'http://openid.net/signon/1.1',
+            'openid.ns.sreg': 'http://openid.net/extensions/sreg/1.1',
+            'openid.return_to': 'http://drupal.invalid/return_to',
+            'openid.sreg.required': 'nickname,email',
+            'openid.trust_root': 'http://drupal.invalid',
+            }
+        m = message.Message.fromPostArgs(query)
+        self.failUnless(m.isOpenID1())
+
+
+
 class NamespaceMapTest(unittest.TestCase):
     def test_onealias(self):
         nsm = message.NamespaceMap()
@@ -778,14 +1009,14 @@ class NamespaceMapTest(unittest.TestCase):
             self.failUnless(nsm.isDefined(uripat%(n-1)))
             nsm.add(uripat%n)
 
-        for (uri, alias) in nsm.iteritems():
+        for (uri, alias) in nsm.items():
             self.failUnless(uri[22:]==alias[3:])
 
         i=0
         it = nsm.iterAliases()
         try:
             while True:
-                it.next()
+                next(it)
                 i += 1
         except StopIteration:
             self.failUnless(i == 23)
@@ -794,7 +1025,7 @@ class NamespaceMapTest(unittest.TestCase):
         it = nsm.iterNamespaceURIs()
         try:
             while True:
-                it.next()
+                next(it)
                 i += 1
         except StopIteration:
             self.failUnless(i == 23)
