@@ -1,6 +1,6 @@
 
 import unittest
-from support import CatchLogs
+from .support import CatchLogs
 
 from openid.message import Message, OPENID2_NS, OPENID1_NS, OPENID_NS
 from openid import association
@@ -57,7 +57,7 @@ class TestOpenID2SessionNegotiation(unittest.TestCase, CatchLogs):
         msg = Message(self.endpoint.preferredNamespace())
         msg.setArg(OPENID_NS, 'error', 'Unsupported type')
         msg.setArg(OPENID_NS, 'error_code', 'unsupported-type')
-        msg.setArg(OPENID_NS, 'assoc_type', None)
+        # not set: msg.delArg(OPENID_NS, 'assoc_type')
         msg.setArg(OPENID_NS, 'session_type', 'new-session-type')
 
         self.consumer.return_messages = [msg]
@@ -76,7 +76,7 @@ class TestOpenID2SessionNegotiation(unittest.TestCase, CatchLogs):
         msg.setArg(OPENID_NS, 'error', 'Unsupported type')
         msg.setArg(OPENID_NS, 'error_code', 'unsupported-type')
         msg.setArg(OPENID_NS, 'assoc_type', 'new-assoc-type')
-        msg.setArg(OPENID_NS, 'session_type', None)
+        # not set: msg.setArg(OPENID_NS, 'session_type', None)
 
         self.consumer.return_messages = [msg]
         self.assertEqual(self.consumer._negotiateAssociation(self.endpoint), None)
@@ -91,9 +91,7 @@ class TestOpenID2SessionNegotiation(unittest.TestCase, CatchLogs):
         preferred (assoc_type, session_type) combination that is not
         allowed by the consumer's SessionNegotiator.
         """
-        allowed_types = [
-            ('assoc_bogus', 'session_bogus'),
-            ]
+        allowed_types = []
 
         negotiator = association.SessionNegotiator(allowed_types)
         self.consumer.negotiator = negotiator
@@ -165,8 +163,8 @@ class TestOpenID1SessionNegotiation(unittest.TestCase, CatchLogs):
     Tests for the OpenID 1 consumer association session behavior.  See
     the docs for TestOpenID2SessionNegotiation.  Notice that this
     class is not a subclass of the OpenID 2 tests.  Instead, it uses
-    many of the same inputs but inspects the log messages logged with
-    oidutil.log.  See the calls to self.failUnlessLogMatches.  Some of
+    many of the same inputs but inspects the log messages.
+    See the calls to self.failUnlessLogMatches.  Some of
     these tests pass openid2-style messages to the openid 1
     association processing logic to be sure it ignores the extra data.
     """
@@ -187,7 +185,7 @@ class TestOpenID1SessionNegotiation(unittest.TestCase, CatchLogs):
         msg = Message(self.endpoint.preferredNamespace())
         msg.setArg(OPENID_NS, 'error', 'Unsupported type')
         msg.setArg(OPENID_NS, 'error_code', 'unsupported-type')
-        msg.setArg(OPENID_NS, 'assoc_type', None)
+        # not set: msg.setArg(OPENID_NS, 'assoc_type', None)
         msg.setArg(OPENID_NS, 'session_type', 'new-session-type')
 
         self.consumer.return_messages = [msg]
@@ -200,7 +198,7 @@ class TestOpenID1SessionNegotiation(unittest.TestCase, CatchLogs):
         msg.setArg(OPENID_NS, 'error', 'Unsupported type')
         msg.setArg(OPENID_NS, 'error_code', 'unsupported-type')
         msg.setArg(OPENID_NS, 'assoc_type', 'new-assoc-type')
-        msg.setArg(OPENID_NS, 'session_type', None)
+        # not set: msg.setArg(OPENID_NS, 'session_type', None)
 
         self.consumer.return_messages = [msg]
         self.assertEqual(self.consumer._negotiateAssociation(self.endpoint), None)
@@ -208,9 +206,7 @@ class TestOpenID1SessionNegotiation(unittest.TestCase, CatchLogs):
         self.failUnlessLogMatches('Server error when requesting an association')
 
     def testNotAllowed(self):
-        allowed_types = [
-            ('assoc_bogus', 'session_bogus'),
-            ]
+        allowed_types = []
 
         negotiator = association.SessionNegotiator(allowed_types)
         self.consumer.negotiator = negotiator
@@ -252,8 +248,8 @@ class TestOpenID1SessionNegotiation(unittest.TestCase, CatchLogs):
 class TestNegotiatorBehaviors(unittest.TestCase, CatchLogs):
     def setUp(self):
         self.allowed_types = [
-            ('assoc1', 'session1'),
-            ('assoc2', 'session2'),
+            ('HMAC-SHA1', 'no-encryption'),
+            ('HMAC-SHA256', 'no-encryption'),
             ]
 
         self.n = association.SessionNegotiator(self.allowed_types)
