@@ -1,5 +1,5 @@
 from openid.yadis.parsehtml import YadisHTMLParser, ParseDone
-from HTMLParser import HTMLParseError
+from html.parser import HTMLParseError
 
 import os.path, unittest, sys
 
@@ -15,9 +15,9 @@ class _TestCase(unittest.TestCase):
 
     def runTest(self):
         p = YadisHTMLParser()
-        try:
+	try:
             p.feed(self.case)
-        except ParseDone, why:
+        except ParseDone as why:
             found = why[0]
 
             # make sure we protect outselves against accidental bogus
@@ -31,7 +31,7 @@ class _TestCase(unittest.TestCase):
             msg = "%r != %r for case %s" % (found, self.expected, self.case)
             self.failUnlessEqual(found, self.expected, msg)
         except HTMLParseError:
-            assert self.expected == 'None'
+            self.failUnless(self.expected == 'None', (self.case, self.expected))
         else:
             self.failUnless(self.expected == 'EOF', (self.case, self.expected))
 
@@ -57,7 +57,7 @@ def pyUnitTests():
 
 def test():
     runner = unittest.TextTestRunner()
-    return runner.run(loadTests())
+    return runner.run(pyUnitTests())
 
 filenames = ['data/test1-parsehtml.txt']
 
