@@ -140,7 +140,7 @@ class SRegRequestTest(unittest.TestCase):
             ValueError,
             sreg.SRegRequest, ['elvis'])
 
-    def test_fromOpenIDResponse(self):
+    def test_fromOpenIDRequest(self):
         args = {}
         ns_sentinel = object()
         args_sentinel = object()
@@ -177,7 +177,8 @@ class SRegRequestTest(unittest.TestCase):
 
     def test_parseExtensionArgs_empty(self):
         req = sreg.SRegRequest()
-        req.parseExtensionArgs({})
+        results = req.parseExtensionArgs({})
+        self.failUnlessEqual(None, results)
 
     def test_parseExtensionArgs_extraIgnored(self):
         req = sreg.SRegRequest()
@@ -444,7 +445,7 @@ class SRegResponseTest(unittest.TestCase):
         sreg_resp = sreg.SRegResponse.fromSuccessResponse(success_resp,
                                                           signed_only=False)
         self.failUnlessEqual([('nickname', 'The Mad Stork')],
-                             sreg_resp.items())
+                             list(sreg_resp.items()))
 
 class SendFieldsTest(unittest.TestCase):
     def test(self):
