@@ -15,15 +15,15 @@ class UrinormTest(unittest.TestCase):
     def runTest(self):
         try:
             actual = openid.urinorm.urinorm(self.case)
-        except ValueError:
-            self.assertEqual(self.expected, 'fail')
+        except ValueError as why:
+            self.assertEqual(self.expected, 'fail', why)
         else:
             self.assertEqual(actual, self.expected)
 
     def parse(cls, full_case):
         desc, case, expected = full_case.split('\n')
-        case = unicode(case, 'utf-8')
-        
+        case = str(case, 'utf-8')
+
         return cls(desc, case, expected)
 
     parse = classmethod(parse)
