@@ -17,7 +17,7 @@ class DiscoveryVerificationTest(OpenIDTestMixin, TestIdRes):
     def failUnlessProtocolError(self, prefix, callable, *args, **kwargs):
         try:
             result = callable(*args, **kwargs)
-        except consumer.ProtocolError, e:
+        except consumer.ProtocolError as e:
             self.failUnless(
                 e[0].startswith(prefix),
                 'Expected message prefix %r, got message %r' % (prefix, e[0]))
@@ -133,8 +133,10 @@ class DiscoveryVerificationTest(OpenIDTestMixin, TestIdRes):
         endpoint.server_url = 'Phone Home'
         endpoint.type_uris = [discover.OPENID_1_1_TYPE]
 
-        def discoverAndVerify(to_match):
-            self.failUnlessEqual(endpoint.claimed_id, to_match.claimed_id)
+        def discoverAndVerify(claimed_id, to_match_endpoints):
+            self.failUnlessEqual(claimed_id, endpoint.claimed_id)
+            for to_match in to_match_endpoints:
+                self.failUnlessEqual(claimed_id, to_match.claimed_id)
             raise consumer.ProtocolError(text)
 
         self.consumer._discoverAndVerify = discoverAndVerify
@@ -147,7 +149,7 @@ class DiscoveryVerificationTest(OpenIDTestMixin, TestIdRes):
 
         try:
             r = self.consumer._verifyDiscoveryResults(msg, endpoint)
-        except consumer.ProtocolError, e:
+        except consumer.ProtocolError as e:
             # Should we make more ProtocolError subclasses?
             self.failUnless(str(e), text)
         else:
@@ -173,7 +175,7 @@ class DiscoveryVerificationTest(OpenIDTestMixin, TestIdRes):
     def test_openid1UsePreDiscoveredWrongType(self):
         class VerifiedError(Exception): pass
 
-        def discoverAndVerify(_to_match):
+        def discoverAndVerify(claimed_id, _to_match):
             raise VerifiedError
 
         self.consumer._discoverAndVerify = discoverAndVerify
@@ -210,15 +212,39 @@ class DiscoveryVerificationTest(OpenIDTestMixin, TestIdRes):
              'claimed_id': claimed_id_frag,
              'op_endpoint': endpoint.server_url})
         result = self.consumer._verifyDiscoveryResults(msg, endpoint)
-        
+
         self.failUnlessEqual(result.local_id, endpoint.local_id)
         self.failUnlessEqual(result.server_url, endpoint.server_url)
         self.failUnlessEqual(result.type_uris, endpoint.type_uris)
 
         self.failUnlessEqual(result.claimed_id, claimed_id_frag)
-        
+
         self.failUnlessLogEmpty()
 
+    def test_openid1Fallback1_0(self):
+        claimed_id = 'http://claimed.id/'
+        endpoint = None
+        resp_mesg = message.Message.fromOpenIDArgs({
+            'ns': message.OPENID1_NS,
+            'identity': claimed_id})
+        # Pass the OpenID 1 claimed_id this way since we're passing
+        # None for the endpoint.
+        resp_mesg.setArg(message.BARE_NS, 'openid1_claimed_id', claimed_id)
+
+        # We expect the OpenID 1 discovery verification to try
+        # matching the discovered endpoint against the 1.1 type and
+        # fall back to 1.0.
+        expected_endpoint = discover.OpenIDServiceEndpoint()
+        expected_endpoint.type_uris = [discover.OPENID_1_0_TYPE]
+        expected_endpoint.local_id = None
+        expected_endpoint.claimed_id = claimed_id
+
+        discovered_services = [expected_endpoint]
+        self.consumer._discover = lambda *args: ('unused', discovered_services)
+
+        actual_endpoint = self.consumer._verifyDiscoveryResults(
+            resp_mesg, endpoint)
+        self.failUnless(actual_endpoint is expected_endpoint)
 
 # XXX: test the implementation of _discoverAndVerify
 
